==> blastengine-0.0.2.tar.gz: blastengine-0.0.2/blastengine/Transaction.py <==
from blastengine.MailBase import MailBase
from pathlib import Path
import requests
import json
import mimetypes

class Transaction(MailBase):
	post_url = 'https://app.engn.jp/api/v1/deliveries/transaction'
	def send(self):
		if len(self._attachments) > 0:
			return self.send_attachments_mail()
		return self.send_text_mail()

	def generate_params(self):
		entity = {
			'subject': self._subject,
			'encode': self._encode,
			'text_part': self._text_part,
			'from': {
				'email': self._from['email']
			},
			'to': ",".join(self._to)
		}
		if 'name' in self._from:
			entity['from']['name'] = self._from['name']
		if self._html_part is not None:
			entity['html_part'] = self._html_part
		return entity

	def send_text_mail(self):
		entity = self.generate_params()
		headers = {
			'Authorization': f'Bearer {self.client.token}',
			'content-type': 'application/json'
		}
		response = requests.post(Transaction.post_url, data=json.dumps(entity), headers=headers)
		return self.handle_response(response)

	def handle_response(self, response):
		json_body = json.loads(response.content)
		if response.status_code > 300:
			messages = []
			for key in json_body['error_messages']:
				messages.append(f"{key}: {', '.join(json_body['error_messages'][key])}")
			raise Exception("\n".join(messages))
		return json_body['delivery_id']

	def send_attachments_mail(self):
		entity = self.generate_params()
		headers = {
			'Authorization': f'Bearer {self.client.token}'
		}
		files = []
		for file_path in self._attachments:
			file = Path(file_path)
			files.append(('file', (file.name, open(file.resolve(), 'rb'), mimetypes.guess_type(file.resolve()))))
		files.append(('data', ('data.json', json.dumps(entity), 'application/json')))
		response = requests.post(Transaction.post_url, files=files, headers=headers)
		return self.handle_response(response)

==> blastengine-0.0.7.tar.gz: blastengine-0.0.7/blastengine/Transaction.py <==
from blastengine.MailBase import MailBase
from pathlib import Path
import requests
import json
import mimetypes

class Transaction(MailBase):
	post_url = 'https://app.engn.jp/api/v1/deliveries/transaction'
	def send(self):
		if len(self._attachments) > 0:
			return self.send_attachments_mail()
		return self.send_text_mail()

	def generate_params(self):
		entity = {
			'subject': self._subject,
			'encode': self._encode,
			'text_part': self._text_part,
			'from': {
				'email': self._from['email']
			},
			'to': self._to
		}
		if 'name' in self._from:
			entity['from']['name'] = self._from['name']
		if len(self._insert_code) > 0:
			entity['insert_code'] = self._insert_code
		if self._html_part is not None:
			entity['html_part'] = self._html_part
		return entity

	def send_text_mail(self):
		entity = self.generate_params()
		headers = {
			'Authorization': f'Bearer {self.client.token}',
			'content-type': 'application/json'
		}
		response = requests.post(Transaction.post_url, data=json.dumps(entity), headers=headers)
		return self.handle_response(response)

	def send_attachments_mail(self):
		entity = self.generate_params()
		headers = {
			'Authorization': f'Bearer {self.client.token}'
		}
		files = []
		fs = []
		for file_path in self._attachments:
			file = Path(file_path)
			f = open(file.resolve(), 'rb')
			files.append(('file', (file.name, f, mimetypes.guess_type(file.resolve()))))
			fs.append(f)
		files.append(('data', ('data.json', json.dumps(entity), 'application/json')))
		response = requests.post(Transaction.post_url, files=files, headers=headers)
		for f in fs:
			f.close()
		return self.handle_response(response)
